
# Type: chemical to chemical derivation association_change is catalyzed by




URI: [biolink:chemical_to_chemical_derivation_association_change_is_catalyzed_by](https://w3id.org/biolink/vocab/chemical_to_chemical_derivation_association_change_is_catalyzed_by)


## Domain and Range

[ChemicalToChemicalDerivationAssociation](ChemicalToChemicalDerivationAssociation.md) ->  <sub>0..*</sub> [MacromolecularMachine](MacromolecularMachine.md)

## Parents

 *  is_a: [change is catalyzed by](change_is_catalyzed_by.md)

## Children


## Used by

 * [ChemicalToChemicalDerivationAssociation](ChemicalToChemicalDerivationAssociation.md)
